@@ -1,6 +1,6 @@
 use std::convert::TryInto;
 
-#[cfg(feature = "bitvec_0_22")]
+#[cfg(feature = "bitvec")]
 mod bitvec;
 mod dynamic_struct_index_reader;
 mod dynamic_struct_index_writer;
@@ -40,10 +40,11 @@ where
 	let position = bytes.len() - std::mem::size_of::<PointerType>();
 	let position = position.try_into().unwrap();
 	let position = Position::new(position);
-	<Pointer<T>>::read(&bytes, position)
+	<Pointer<T>>::read(bytes, position)
 }
 
 #[cfg(test)]
+#[allow(unused)]
 mod test {
 	use crate as buffalo;
 
